contexttools.detach_time_signature_mark_attached_to_component
=============================================================

.. autofunction:: abjad.tools.contexttools.detach_time_signature_mark_attached_to_component
